@@ -164,9 +164,9 @@ void MainWindow::readgtkrc()
     icontheme.remove(QChar(' '));
     icontheme.simplified();
     int indeksi = ui->Iconset->findText(icontheme);
-    if (indeksi) {
+ //   if (indeksi) {
         ui->Iconset->removeItem(indeksi);
-    }
+  //  }
   //  ui->Iconset->setDuplicatesEnabled();
   //  ui->Iconset->insertPolicy(1);
     ui->Iconset->insertItem(0, icontheme);
